@@ -8,7 +8,7 @@ path = os.path.join('.', os.path.dirname(__file__), '../')
 sys.path.append(path)
 
 from flask import Flask, g, render_template
-from flaskext.sijax import init_sijax, route
+import flask_sijax
 
 app = Flask(__name__)
 
@@ -20,7 +20,7 @@ app.config["SIJAX_STATIC_PATH"] = os.path.join('.', os.path.dirname(__file__), '
 # browsers that don't support JSON natively (like IE <= 7)
 app.config["SIJAX_JSON_URI"] = '/static/js/sijax/json2.js'
 
-init_sijax(app)
+flask_sijax.Sijax(app)
 
 class SijaxHandler(object):
     """A container class for all Sijax handlers.
@@ -67,15 +67,15 @@ class SijaxHandler(object):
 
         # Clear the messages container
         obj_response.html('#messages', '')
-        
+
         # Clear the textbox
         obj_response.attr('#message', 'value', '')
 
         # Ensure the texbox has focus
         obj_response.script("$('#message').focus();")
-        
 
-@route(app, "/")
+
+@flask_sijax.route(app, "/")
 def index():
     if g.sijax.is_sijax_request:
         # The request looks like a valid Sijax request
@@ -86,5 +86,4 @@ def index():
     return render_template('chat.html')
 
 if __name__ == '__main__':
-    app.run(debug=True, port=8080) 
-
+    app.run(debug=True, port=8080)
